<?php
/**
 * Plugin Name: Elementor Tracker
 * Description: Tracking Functionality with Elementor.
 * Plugin URI:  https://assafdev.io/
 * Version:     0.1.5
 * Author:      Assaf Shalin
 * Author URI:  https://assafdev.io/
 * Text Domain: elementor-tracker
 */
define('ELEMENTOR_TRACKER_CURRENT_VERSION', '0.1.5');
if ( ! defined( 'ABSPATH' ) ) exit;


final class Elementor_Tracker {

	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';
	const MINIMUM_PHP_VERSION = '7.0';

	public function __construct() {
		add_action( 'plugins_loaded', array( $this, 'init' ), -999  );
	}

	public function init() {

		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notice_missing_main_plugin' ) );
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notice_minimum_elementor_version' ) );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notice_minimum_php_version' ) );
			return;
		}

		require_once( 'plugin.php' );
		Elementor_Tracker\Elementor_Tracker_Plugin::instance();
	}


	public function admin_notice_missing_main_plugin() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'elementor-tracker' ),
			'<strong>' . esc_html__( 'Elementor Tracker', 'elementor-tracker' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'elementor-tracker' ) . '</strong>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}

	public function admin_notice_minimum_elementor_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'elementor-tracker' ),
			'<strong>' . esc_html__( 'Elementor Tracker', 'elementor-tracker' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'elementor-tracker' ) . '</strong>',
			self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}

	public function admin_notice_minimum_php_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'elementor-tracker' ),
			'<strong>' . esc_html__( 'Elementor Tracker', 'elementor-tracker' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'elementor-tracker' ) . '</strong>',
			self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}
}

new Elementor_Tracker();


require_once('elementor-tracker-updater.php');
new Elementor_Tracker_Updater();