<?php
namespace Elementor_Tracker;
use Elementor;

class Elementor_Tracker_Plugin {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}


	public function __construct() {
		add_action( 'elementor/element/section/section_advanced/after_section_end', array( $this, 'add_tracking_controls' ), 10, 2 );
		add_action( 'elementor/element/column/section_advanced/after_section_end', array( $this, 'add_tracking_controls' ), 10, 2 );
		add_action( 'elementor/element/common/_section_responsive/after_section_end', array( $this, 'add_tracking_controls' ), 10, 2 );
		
		add_action( 'elementor/frontend/section/before_render', array( $this, 'before_render' ) );
		add_action( 'elementor/frontend/element/before_render', array( $this, 'before_render' ) );
		add_action( 'elementor/frontend/column/before_render', array( $this, 'before_render' ) );
		add_action( 'elementor/frontend/element/before_render', array( $this, 'before_render' ) );
		add_action( 'elementor/frontend/widget/before_render', array( $this, 'before_render' ) );

		add_action( 'elementor/frontend/before_enqueue_scripts', array( $this, 'enqueue_scripts' ), 9 );
	}

	public function plugin_url( $path = null ) {

		if ( ! isset($this->plugin_url) ) {
			$this->plugin_url = trailingslashit( plugin_dir_url( __FILE__ ) );
		}

		return $this->plugin_url . $path;
	}

	public function add_tracking_controls($obj) {
		$obj->start_controls_section(
			'elementor_tracker_options',
			array(
				'label' => esc_html__( 'Events Tracking', 'elementor-tracker' ),
				'tab'   => \Elementor\Controls_Manager::TAB_ADVANCED,
			)
		);
		$obj->add_control(
			'elementor_tracker_options_facebook',
			array(
				'label'    => esc_html__('Track with Facebook', 'elementor-tracker'),
				'type'     => Elementor\Controls_Manager::SWITCHER,
				'render_type'        => 'none',
			)
		);
		$obj->add_control(
			'elementor_tracker_options_facebook_event_name',
			array(
				'label'    => esc_html__('Facebook Event', 'elementor-tracker'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'AddPaymentInfo' => esc_html__('AddPaymentInfo', 'elementor-tracker'),
					'AddToCart' => esc_html__('AddToCart', 'elementor-tracker'),
					'AddToWishlist' => esc_html__('AddToWishlist', 'elementor-tracker'),
					'CompleteRegistration' => esc_html__('CompleteRegistration', 'elementor-tracker'),
					'Contact' => esc_html__('Contact', 'elementor-tracker'),
					'CustomizeProduct' => esc_html__('CustomizeProduct', 'elementor-tracker'),
					'Donate' => esc_html__('Donate', 'elementor-tracker'),
					'FindLocation' => esc_html__('FindLocation', 'elementor-tracker'),
					'InitiateCheckout' => esc_html__('InitiateCheckout', 'elementor-tracker'),
					'Lead' => esc_html__('Lead', 'elementor-tracker'),
					'Purchase' => esc_html__('Purchase', 'elementor-tracker'),
					'Schedule' => esc_html__('Schedule', 'elementor-tracker'),
					'Search' => esc_html__('Search', 'elementor-tracker'),
					'StartTrial' => esc_html__('StartTrial', 'elementor-tracker'),
					'SubmitApplication' => esc_html__('SubmitApplication', 'elementor-tracker'),
					'Subscribe' => esc_html__('Subscribe', 'elementor-tracker'),
					'ViewContent' => esc_html__('ViewContent', 'elementor-tracker'),
					'Custom' => esc_html__('Custom', 'elementor-tracker'),
				],
				'default' => 'ViewContent',
				'condition' => array(
					'elementor_tracker_options_facebook' => 'yes',
				),
				'render_type'        => 'none',
			)
		);
		
		$obj->add_control(
			'elementor_tracker_options_facebook_event_name_custom',
			array(
				'label'    => esc_html__('Custom Event', 'elementor-tracker'),
				'type'     => Elementor\Controls_Manager::TEXT,
				'show_label' => true,
				'placeholder' => esc_html__('i.e Whatsapp', 'elementor-tracker'),
				'condition' => array(
					'elementor_tracker_options_facebook' => 'yes',
					'elementor_tracker_options_facebook_event_name' => 'Custom',
				),
				'render_type'        => 'none',
			)
		);
		$obj->add_control(
			'elementor_tracker_options_ga',
			array(
				'label'    => esc_html__('Track with Google Analytics (analytics.js)', 'elementor-tracker'),
				'type'     => Elementor\Controls_Manager::SWITCHER,
				'render_type'        => 'none',
			)
		);
		$obj->add_control(
			'elementor_tracker_options_ga_category',
			array(
				'label'    => esc_html__('Event Category', 'elementor-tracker'),
				'type'     => Elementor\Controls_Manager::TEXT,
				'show_label' => true,
				'placeholder' => esc_html__('i.e Outbound Link', 'elementor-tracker'),
				'condition' => array(
					'elementor_tracker_options_ga' => 'yes',
				),
				'render_type'        => 'none',
			)
		);
		$obj->add_control(
			'elementor_tracker_options_ga_action',
			array(
				'label'    => esc_html__('Event Action', 'elementor-tracker'),
				'type'     => Elementor\Controls_Manager::TEXT,
				'show_label' => true,
				'placeholder' => esc_html__('i.e click', 'elementor-tracker'),
				'condition' => array(
					'elementor_tracker_options_ga' => 'yes',
				),
				'render_type'        => 'none',
			)
		);
		$obj->add_control(
			'elementor_tracker_options_ga_label',
			array(
				'label'    => esc_html__('Event Label', 'elementor-tracker'),
				'type'     => Elementor\Controls_Manager::TEXT,
				'show_label' => true,
				'placeholder' => esc_html__('i.e Fall Campaign', 'elementor-tracker'),
				'condition' => array(
					'elementor_tracker_options_ga' => 'yes',
				),
				'render_type'        => 'none',
			)
		);
		$obj->add_control(
			'elementor_tracker_options_gtag',
			array(
				'label'    => esc_html__('Track with Google Universal Tag (gtag.js)', 'elementor-tracker'),
				'type'     => Elementor\Controls_Manager::SWITCHER,
				'render_type'        => 'none',
			)
		);
		$obj->add_control(
			'elementor_tracker_options_gtag_name',
			array(
				'label'    => esc_html__('Event Name', 'elementor-tracker'),
				'type'     => Elementor\Controls_Manager::TEXT,
				'show_label' => true,
				'placeholder' => esc_html__('i.e Lead', 'elementor-tracker'),
				'condition' => array(
					'elementor_tracker_options_gtag' => 'yes',
				),
				'render_type'        => 'none',
			)
		);
		$obj->add_control(
			'elementor_tracker_options_aw',
			array(
				'label'    => esc_html__('Track Adwords Converstion (gtag.js)', 'elementor-tracker'),
				'type'     => Elementor\Controls_Manager::SWITCHER,
				'render_type'        => 'none',
			)
		);
		$obj->add_control(
			'elementor_tracker_options_aw_conversion',
			array(
				'label'    => esc_html__('Conversion', 'elementor-tracker'),
				'type'     => Elementor\Controls_Manager::TEXT,
				'show_label' => true,
				'placeholder' => esc_html__('i.e AW-XXXXXXXX/XXXXXXXXX', 'elementor-tracker'),
				'condition' => array(
					'elementor_tracker_options_aw' => 'yes',
				),
				'render_type'        => 'none',
			)
		);
		$obj->end_controls_section();
	}

	public function before_render($element) {
		$data     = $element->get_data();
		$settings = $data['settings'];
		$element_type = $data['elType'];
		$attr = array();
		$has_tracking = false;
		$has_fb_tracking = false;
		$has_ga_tracking = false;
		$has_gtag_tracking = false;
		$has_aw_tracking = false;
		if(isset($settings['elementor_tracker_options_facebook'])) {
			$has_fb_tracking = filter_var( $settings['elementor_tracker_options_facebook'], FILTER_VALIDATE_BOOLEAN );
		}
		if(isset($settings['elementor_tracker_options_ga'])) {
			$has_ga_tracking = filter_var( $settings['elementor_tracker_options_ga'], FILTER_VALIDATE_BOOLEAN );
		}
		if(isset($settings['elementor_tracker_options_gtag'])) {
			$has_gtag_tracking = filter_var( $settings['elementor_tracker_options_gtag'], FILTER_VALIDATE_BOOLEAN );
		}
		if(isset($settings['elementor_tracker_options_aw'])) {
			$has_aw_tracking = filter_var( $settings['elementor_tracker_options_aw'], FILTER_VALIDATE_BOOLEAN );
		}
		
		if ($has_fb_tracking) {
			$has_tracking = true;
			$attr['track-fb-event'] = true;
			$attr['fb-event'] = $settings['elementor_tracker_options_facebook_event_name'];
			if(isset($settings['elementor_tracker_options_facebook_event_name_custom'])) {
				$attr['fb-event-custom'] = $settings['elementor_tracker_options_facebook_event_name_custom'];
			}
		}
		if($has_ga_tracking) {
			$has_tracking = true;
			$attr['track-ga-event'] = true;
			$attr['ga-cat'] = $settings['elementor_tracker_options_ga_category'];
			$attr['ga-action'] = $settings['elementor_tracker_options_ga_action'];
			$attr['ga-label'] = $settings['elementor_tracker_options_ga_label'];
		}
		if($has_gtag_tracking) {
			$has_tracking = true;
			$attr['track-gtag-event'] = true;
			$attr['gtag-event-name'] = $settings['elementor_tracker_options_gtag_name'];
		}
		if($has_aw_tracking) {
			$has_tracking = true;
			$attr['track-aw-conv'] = true;
			$attr['aw-conv'] = $settings['elementor_tracker_options_aw_conversion'];
		}
		if ($has_tracking) {
			$element->add_render_attribute( '_wrapper', 
			array(
				'class'         => 'elementor-trackable',
				'data-elementor-tracker' => json_encode( $attr ),
			) );
		}
	}

	public function enqueue_scripts() {
		wp_enqueue_script(
			'elementor-tracker',
			$this->plugin_url( 'scripts/elementor-tracking.js' ),
			array( 'jquery' ),
			'',
			true
		);
	}
	

}
